@@ -3,5 +3,5 @@ Generic exception class for raising custom exceptions
 """
 
 
-class sssException(Exception):
+class SSSException(Exception):
     pass
